use vulkan_context::VulkanContext;
use window_render_context::WindowRenderContext;

use bevy_app::{App, Plugin};

use super::window::raw_handle::WindowWrapper;

mod utils;
mod vulkan_context;
mod window_render_context;

#[derive(Debug, thiserror::Error)]
pub enum VulkanError {
    #[error("Failed to create vulkan context")]
    FailedToCreateVulkanContext,
}

pub struct VulkanPlugin;

impl Plugin for VulkanPlugin {
    fn build(&self, app: &mut App) {
        let vulkan_context = VulkanContext::from(app as &App);
        app.world_mut().insert_resource(vulkan_context);
    }

    fn ready(&self, app: &App) -> bool {
        app.world().get_resource::<WindowWrapper>().is_some()
    }

    fn finish(&self, app: &mut App) {
        let window_render_context = WindowRenderContext::from(app as &App);
        app.world_mut().insert_resource(window_render_context);
    }
}
