use winit::event_loop::{ControlFlow, EventLoop};

use bevy_app::{App, AppExit};

pub mod core;
pub mod game;
pub mod old_app;

fn main() {
    env_logger::init();

    run_new_app();
    // run_old_app();
}

fn run_new_app() {
    let mut app = App::default();
    game::init(&mut app);
    match app.run() {
        AppExit::Success => {}
        AppExit::Error(e) => {
            log::error!("Error running new app: {e}");
        }
    }
}

fn run_old_app() {
    let event_loop = EventLoop::new().unwrap();
    event_loop.set_control_flow(ControlFlow::Poll);

    let vulkan_context = old_app::vulkan_context::VulkanContext::from(&event_loop);
    let mut app = old_app::app::App::from(vulkan_context);

    match event_loop.run_app(&mut app) {
        Ok(_) => {}
        Err(e) => {
            log::error!("Error running old app: {e}");
        }
    }
}
